==> istio-model-v1alpha3-6.1.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionFluentImpl<A extends HTTPFaultInjectionFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionFluent<A>{
  public HTTPFaultInjectionFluentImpl() {
  }
  public HTTPFaultInjectionFluentImpl(HTTPFaultInjection instance) {
    this.withAbort(instance.getAbort()); 
    this.withDelay(instance.getDelay()); 
  }
  private HTTPFaultInjectionAbortBuilder abort;
  private HTTPFaultInjectionDelayBuilder delay;
  
  /**
   * This method has been deprecated, please use method buildAbort instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjectionAbort getAbort() {
    return this.abort!=null ?this.abort.build():null;
  }
  public HTTPFaultInjectionAbort buildAbort() {
    return this.abort!=null ?this.abort.build():null;
  }
  public A withAbort(HTTPFaultInjectionAbort abort) {
    _visitables.get("abort").remove(this.abort);
    if (abort!=null){ this.abort= new HTTPFaultInjectionAbortBuilder(abort); _visitables.get("abort").add(this.abort);} else { this.abort = null; _visitables.get("abort").remove(this.abort); } return (A) this;
  }
  public Boolean hasAbort() {
    return this.abort != null;
  }
  public HTTPFaultInjectionFluent.AbortNested<A> withNewAbort() {
    return new HTTPFaultInjectionFluentImpl.AbortNestedImpl();
  }
  public HTTPFaultInjectionFluent.AbortNested<A> withNewAbortLike(HTTPFaultInjectionAbort item) {
    return new HTTPFaultInjectionFluentImpl.AbortNestedImpl(item);
  }
  public HTTPFaultInjectionFluent.AbortNested<A> editAbort() {
    return withNewAbortLike(getAbort());
  }
  public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbort() {
    return withNewAbortLike(getAbort() != null ? getAbort(): new HTTPFaultInjectionAbortBuilder().build());
  }
  public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbortLike(HTTPFaultInjectionAbort item) {
    return withNewAbortLike(getAbort() != null ? getAbort(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjectionDelay getDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  public HTTPFaultInjectionDelay buildDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  public A withDelay(HTTPFaultInjectionDelay delay) {
    _visitables.get("delay").remove(this.delay);
    if (delay!=null){ this.delay= new HTTPFaultInjectionDelayBuilder(delay); _visitables.get("delay").add(this.delay);} else { this.delay = null; _visitables.get("delay").remove(this.delay); } return (A) this;
  }
  public Boolean hasDelay() {
    return this.delay != null;
  }
  public HTTPFaultInjectionFluent.DelayNested<A> withNewDelay() {
    return new HTTPFaultInjectionFluentImpl.DelayNestedImpl();
  }
  public HTTPFaultInjectionFluent.DelayNested<A> withNewDelayLike(HTTPFaultInjectionDelay item) {
    return new HTTPFaultInjectionFluentImpl.DelayNestedImpl(item);
  }
  public HTTPFaultInjectionFluent.DelayNested<A> editDelay() {
    return withNewDelayLike(getDelay());
  }
  public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelay() {
    return withNewDelayLike(getDelay() != null ? getDelay(): new HTTPFaultInjectionDelayBuilder().build());
  }
  public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelayLike(HTTPFaultInjectionDelay item) {
    return withNewDelayLike(getDelay() != null ? getDelay(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPFaultInjectionFluentImpl that = (HTTPFaultInjectionFluentImpl) o;
    if (abort != null ? !abort.equals(that.abort) :that.abort != null) return false;
    if (delay != null ? !delay.equals(that.delay) :that.delay != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay); }
    sb.append("}");
    return sb.toString();
  }
  class AbortNestedImpl<N> extends HTTPFaultInjectionAbortFluentImpl<HTTPFaultInjectionFluent.AbortNested<N>> implements HTTPFaultInjectionFluent.AbortNested<N>,Nested<N>{
    AbortNestedImpl(HTTPFaultInjectionAbort item) {
      this.builder = new HTTPFaultInjectionAbortBuilder(this, item);
    }
    AbortNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortBuilder(this);
    }
    HTTPFaultInjectionAbortBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionFluentImpl.this.withAbort(builder.build());
    }
    public N endAbort() {
      return and();
    }
    
  }
  class DelayNestedImpl<N> extends HTTPFaultInjectionDelayFluentImpl<HTTPFaultInjectionFluent.DelayNested<N>> implements HTTPFaultInjectionFluent.DelayNested<N>,Nested<N>{
    DelayNestedImpl(HTTPFaultInjectionDelay item) {
      this.builder = new HTTPFaultInjectionDelayBuilder(this, item);
    }
    DelayNestedImpl() {
      this.builder = new HTTPFaultInjectionDelayBuilder(this);
    }
    HTTPFaultInjectionDelayBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionFluentImpl.this.withDelay(builder.build());
    }
    public N endDelay() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPFaultInjectionFluentImpl<A extends HTTPFaultInjectionFluent<A>> extends BaseFluent<A> implements HTTPFaultInjectionFluent<A>{
  public HTTPFaultInjectionFluentImpl() {
  }
  public HTTPFaultInjectionFluentImpl(HTTPFaultInjection instance) {
    if (instance != null) {
      this.withAbort(instance.getAbort());
      this.withDelay(instance.getDelay());
    }
  }
  private HTTPFaultInjectionAbortBuilder abort;
  private HTTPFaultInjectionDelayBuilder delay;
  
  /**
   * This method has been deprecated, please use method buildAbort instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjectionAbort getAbort() {
    return this.abort!=null ?this.abort.build():null;
  }
  public HTTPFaultInjectionAbort buildAbort() {
    return this.abort!=null ?this.abort.build():null;
  }
  public A withAbort(HTTPFaultInjectionAbort abort) {
    _visitables.get("abort").remove(this.abort);
    if (abort!=null){ this.abort= new HTTPFaultInjectionAbortBuilder(abort); _visitables.get("abort").add(this.abort);} else { this.abort = null; _visitables.get("abort").remove(this.abort); } return (A) this;
  }
  public Boolean hasAbort() {
    return this.abort != null;
  }
  public HTTPFaultInjectionFluentImpl.AbortNested<A> withNewAbort() {
    return new HTTPFaultInjectionFluentImpl.AbortNestedImpl();
  }
  public HTTPFaultInjectionFluentImpl.AbortNested<A> withNewAbortLike(HTTPFaultInjectionAbort item) {
    return new HTTPFaultInjectionFluentImpl.AbortNestedImpl(item);
  }
  public HTTPFaultInjectionFluentImpl.AbortNested<A> editAbort() {
    return withNewAbortLike(getAbort());
  }
  public HTTPFaultInjectionFluentImpl.AbortNested<A> editOrNewAbort() {
    return withNewAbortLike(getAbort() != null ? getAbort(): new HTTPFaultInjectionAbortBuilder().build());
  }
  public HTTPFaultInjectionFluentImpl.AbortNested<A> editOrNewAbortLike(HTTPFaultInjectionAbort item) {
    return withNewAbortLike(getAbort() != null ? getAbort(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildDelay instead.
   * @return The buildable object.
   */
  @Deprecated
  public HTTPFaultInjectionDelay getDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  public HTTPFaultInjectionDelay buildDelay() {
    return this.delay!=null ?this.delay.build():null;
  }
  public A withDelay(HTTPFaultInjectionDelay delay) {
    _visitables.get("delay").remove(this.delay);
    if (delay!=null){ this.delay= new HTTPFaultInjectionDelayBuilder(delay); _visitables.get("delay").add(this.delay);} else { this.delay = null; _visitables.get("delay").remove(this.delay); } return (A) this;
  }
  public Boolean hasDelay() {
    return this.delay != null;
  }
  public HTTPFaultInjectionFluentImpl.DelayNested<A> withNewDelay() {
    return new HTTPFaultInjectionFluentImpl.DelayNestedImpl();
  }
  public HTTPFaultInjectionFluentImpl.DelayNested<A> withNewDelayLike(HTTPFaultInjectionDelay item) {
    return new HTTPFaultInjectionFluentImpl.DelayNestedImpl(item);
  }
  public HTTPFaultInjectionFluentImpl.DelayNested<A> editDelay() {
    return withNewDelayLike(getDelay());
  }
  public HTTPFaultInjectionFluentImpl.DelayNested<A> editOrNewDelay() {
    return withNewDelayLike(getDelay() != null ? getDelay(): new HTTPFaultInjectionDelayBuilder().build());
  }
  public HTTPFaultInjectionFluentImpl.DelayNested<A> editOrNewDelayLike(HTTPFaultInjectionDelay item) {
    return withNewDelayLike(getDelay() != null ? getDelay(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPFaultInjectionFluentImpl that = (HTTPFaultInjectionFluentImpl) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;

    if (!java.util.Objects.equals(delay, that.delay)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay); }
    sb.append("}");
    return sb.toString();
  }
  class AbortNestedImpl<N> extends HTTPFaultInjectionAbortFluentImpl<HTTPFaultInjectionFluentImpl.AbortNested<N>> implements HTTPFaultInjectionFluentImpl.AbortNested<N>,Nested<N>{
    AbortNestedImpl(HTTPFaultInjectionAbort item) {
      this.builder = new HTTPFaultInjectionAbortBuilder(this, item);
    }
    AbortNestedImpl() {
      this.builder = new HTTPFaultInjectionAbortBuilder(this);
    }
    HTTPFaultInjectionAbortBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionFluentImpl.this.withAbort(builder.build());
    }
    public N endAbort() {
      return and();
    }
    
  }
  class DelayNestedImpl<N> extends HTTPFaultInjectionDelayFluentImpl<HTTPFaultInjectionFluentImpl.DelayNested<N>> implements HTTPFaultInjectionFluentImpl.DelayNested<N>,Nested<N>{
    DelayNestedImpl(HTTPFaultInjectionDelay item) {
      this.builder = new HTTPFaultInjectionDelayBuilder(this, item);
    }
    DelayNestedImpl() {
      this.builder = new HTTPFaultInjectionDelayBuilder(this);
    }
    HTTPFaultInjectionDelayBuilder builder;
    public N and() {
      return (N) HTTPFaultInjectionFluentImpl.this.withDelay(builder.build());
    }
    public N endDelay() {
      return and();
    }
    
  }
  
}
